# Table of Contents

- [migration-of-sap-leanix-academy-courses-to-sap-learning](<./migration-of-sap-leanix-academy-courses-to-sap-learning.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Migration of SAP LeanIX Academy Courses to SAP Learning](<./Migration-of-SAP-LeanIX-Academy-Courses-to-SAP-Learning.md>)
  - [Overview](<./Migration-of-SAP-LeanIX-Academy-Courses-to-SAP-Learning/Overview.md>)
  - [What You Need to Do](<./Migration-of-SAP-LeanIX-Academy-Courses-to-SAP-Learning/What-You-Need-to-Do.md>)
  - [Download Your Course History and Certificates from SAP LeanIX Academy](<./Migration-of-SAP-LeanIX-Academy-Courses-to-SAP-Learning/Download-Your-Course-History-and-Certificates-from-SAP-LeanIX-Academy.md>)
  - [Courses on SAP Learning: Links](<./Migration-of-SAP-LeanIX-Academy-Courses-to-SAP-Learning/Courses-on-SAP-Learning-Links.md>)
  - [FAQs](<./Migration-of-SAP-LeanIX-Academy-Courses-to-SAP-Learning/FAQs.md>)
